@@ -8,10 +8,8 @@ from . import async_tail
 @click.command()
 @click.argument("filename")
 def cli(filename):
-
     async def print_line():
         async for line in async_tail(filename):
             print(line)
 
-    loop = asyncio.get_event_loop()
-    loop.run_until_complete(print_line())
+    asyncio.run(print_line())
